import typer


def create_app(name: str, help: str) -> typer.Typer:
    return typer.Typer(
        name=name,
        help=help,
        no_args_is_help=True,
        invoke_without_command=True,
        rich_markup_mode="rich",
        pretty_exceptions_enable=False,
    )
